@@ -18,6 +18,12 @@ class AppSettings(object):
     def SOCIALACCOUNT_ENABLED(self):
         return apps.is_installed("allauth.socialaccount")
 
+    @property
+    def SOCIALACCOUNT_ONLY(self) -> bool:
+        from allauth.utils import get_setting
+
+        return get_setting("SOCIALACCOUNT_ONLY", False)
+
     @property
     def MFA_ENABLED(self):
         return apps.is_installed("allauth.mfa")
@@ -26,6 +32,16 @@ class AppSettings(object):
     def USERSESSIONS_ENABLED(self):
         return apps.is_installed("allauth.usersessions")
 
+    @property
+    def HEADLESS_ENABLED(self):
+        return apps.is_installed("allauth.headless")
+
+    @property
+    def HEADLESS_ONLY(self) -> bool:
+        from allauth.utils import get_setting
+
+        return get_setting("HEADLESS_ONLY", False)
+
     @property
     def DEFAULT_AUTO_FIELD(self):
         return self._setting("DEFAULT_AUTO_FIELD", None)
